import { defineNuxtModule, createResolver, addComponent, addImports, addServerImports, addTemplate } from '@nuxt/kit';
import { genSafeVariableName } from 'knitwork';

const name = "@zinkawaii/nuxt-shiki";
const version = "0.6.0";

const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "shiki"
  },
  defaults: {
    bundledLangs: ["typescript", "javascript", "json"],
    bundledThemes: ["min-light", "min-dark"]
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    addComponent({
      filePath: resolver.resolve("./runtime/component"),
      name: "Shiki"
    });
    addImports([
      {
        name: "getShikiHighlighter",
        from: resolver.resolve("./runtime/utils")
      },
      {
        name: "resolveShikiOptions",
        from: resolver.resolve("./runtime/utils")
      },
      {
        name: "useShikiHighlighted",
        from: resolver.resolve("./runtime/utils")
      }
    ]);
    addServerImports([
      {
        name: "getShikiHighlighter",
        from: resolver.resolve("./runtime/utils")
      },
      {
        name: "resolveShikiOptions",
        from: resolver.resolve("./runtime/utils")
      }
    ]);
    if (options.dynamic) {
      addImports([
        {
          name: "loadShikiLanguages",
          from: resolver.resolve("./runtime/utils")
        }
      ]);
      addServerImports([
        {
          name: "loadShikiLanguages",
          from: resolver.resolve("./runtime/utils")
        }
      ]);
    }
    const bundledThemes = Array.from(
      /* @__PURE__ */ new Set([
        ...options.bundledThemes || [],
        ...typeof options.defaultTheme === "string" ? [options.defaultTheme] : Object.values(options.defaultTheme || {})
      ])
    ).filter(Boolean);
    const bundledLangs = Array.from(
      /* @__PURE__ */ new Set([...options.bundledLangs || [], options.defaultLang])
    ).filter(Boolean);
    const highlightOptions = !options.defaultTheme || typeof options.defaultTheme === "string" ? {
      lang: options.defaultLang || bundledLangs[0] || "javascript",
      theme: options.defaultTheme || bundledThemes[0] || "min-dark",
      ...options.highlightOptions
    } : {
      lang: options.defaultLang || bundledLangs[0] || "javascript",
      themes: {
        ...options.defaultTheme,
        light: options.defaultTheme.light || bundledThemes[0] || "min-light",
        dark: options.defaultTheme.dark || bundledThemes[1] || bundledThemes[0] || "min-dark"
      },
      ...options.highlightOptions
    };
    const template = addTemplate({
      filename: "shiki-options.mjs",
      getContents: () => {
        return (
          /* js */
          `
${bundledThemes.map((theme) => (
            /* js */
            `import { default as _theme_${genSafeVariableName(theme)} } from "shiki/themes/${theme}.mjs";`
          )).join("\n")}
${bundledLangs.map((lang) => (
            /* js */
            `import { default as _lang_${genSafeVariableName(lang)} } from "shiki/langs/${lang}.mjs";`
          )).join("\n")}

export const shikiOptions = {
  highlight: ${JSON.stringify(highlightOptions, null, 2)},
  core: {
    themes: [${bundledThemes.map((theme) => `_theme_${genSafeVariableName(theme)}`).join(", ")}],
    langs: [${bundledLangs.map((lang) => `_lang_${genSafeVariableName(lang)}`).join(", ")}],
    langAlias: ${JSON.stringify(options.langAlias)},
  },
};
`
        );
      }
    });
    nuxt.options.nitro.virtual ||= {};
    nuxt.options.nitro.virtual["shiki-options.mjs"] = template.getContents;
    nuxt.options.alias["shiki-options.mjs"] = template.dst;
  }
});

export { module as default };
